/**
* Each Symbol object represents one entry in a SymbolTable.
*/
public class Symbol {
	/**
	* Construct a new Symbol with unknown values for all fields.
	*/
	public Symbol() {
		this("unnamed",Symbol.UNKNOWN_TYPE,Symbol.UNKNOWN_SCOPE);
	}
	/**
	* Construct a new Symbol.
	* @param name the label by which the program being compiled
	* refers to this Symbol
	* @param t the symbol type, one of the type values defined
	* by the Symbol class.
	* @param s the symbol scope, one of the scope values defined 
	* by the Symbol class.
	*/
	public Symbol(String name,int t,int s) {
		label = name;
		type = t;
		scope = s;
	}
	/**
	* Get the label attribute of this object.
	* @return the Symbol label
	*/
	public String getLabel() {
		return label;
	}
	/**
	* Set the label attribute of this object.
	* @param name the Symbol label
	*/
	public void setLabel(String name) {
		label = name;
	}
	/**
	* Get the type of this Symbol.
	* @return the Symbol type
	*/
	public int getType() {
		return type;
	}
	/**
	* Set the type of this Symbol.
	* @param t the Symbol type
	*/
	public void setType(int t) {
		type = t;
	}
	/**
	* Get the scope of this Symbol.
	* @return the Symbol scope
	*/
	public int getScope() {
		return scope;
	}
	/**
	* Set the scope of this Symbol.
	* @param t the Symbol scope
	*/
	public void setScope(int t) {
		scope = t;
	}
	/**
	* Provide the String that describes this Symbol.
	*/
	public String toString() {
		String s = symbolScope[scope]+" "+symbolType[type]+ " "+label;
		return s;
	}
	
	//--------------------------------------------------
	
	private int type;
	private int scope;
	private String label;
	
	//--------------------------------------------------
	
	private static String[] symbolType = {
		"UNKNOWN","FUNCTION","VARIABLE"
	};
	/** Symbol type: unknown. */
	public static final int UNKNOWN_TYPE	= 0;
	/** Symbol type: function. */
	public static final int FUNCTION	= 1;
	/** Symbol type: variable. */
	public static final int VARIABLE	= 2;
	
	private static String[] symbolScope = {
		"UNKNOWN","LOCAL","PARAMETER","GLOBAL"
	};
	
	/** Symbol scope: unknown. */
	public static final int UNKNOWN_SCOPE	= 0;
	/** Symbol scope: local. */
	public static final int LOCAL		= 1;
	/** Symbol scope: parameter. */
	public static final int PARAMETER	= 2;
	/** Symbol scope: global. */
	public static final int GLOBAL		= 3;
}
